# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/evaluation.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/evaluation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18gateway/evaluation.proto\x12\x07gateway\x1a\x1b\x62uf/validate/validate.proto\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe3\x03\n\nEvaluation\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x36\n\x0b\x63reate_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x19\n\ncreated_by\x18\x03 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12%\n\x06status\x18\x04 \x01(\x0b\x32\x0f.gateway.StatusB\x04\xe2\x41\x01\x03\x12\x1d\n\x0f\x65valuation_type\x18\x05 \x01(\tB\x04\xe2\x41\x01\x02\x12\x19\n\x0b\x64\x65scription\x18\x07 \x01(\tB\x04\xe2\x41\x01\x01\x12*\n\tproviders\x18\x08 \x03(\x0b\x32\x11.gateway.ProviderB\x04\xe2\x41\x01\x02\x12,\n\nassertions\x18\t \x03(\x0b\x32\x12.gateway.AssertionB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03:{\x18\x01\xea\x41g\n\x1b\x61pi.fireworks.ai/Evaluation\x12/accounts/{AccountId}/evaluations/{EvaluationId}*\x0b\x45valuations2\nEvaluation\x82\xf1\x04\x0b\n\x07\x41\x63\x63ount\x18\x01\"\xa6\x02\n\tAssertion\x12>\n\x0e\x61ssertion_type\x18\x01 \x01(\x0e\x32 .gateway.Assertion.AssertionTypeB\x04\xe2\x41\x01\x02\x12,\n\rllm_assertion\x18\x02 \x01(\x0b\x32\x15.gateway.LLMAssertion\x12.\n\x0e\x63ode_assertion\x18\x03 \x01(\x0b\x32\x16.gateway.CodeAssertion\x12\x19\n\x0bmetric_name\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\"`\n\rAssertionType\x12\x1e\n\x1a\x41SSERTION_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12\x41SSERTION_TYPE_LLM\x10\x01\x12\x17\n\x13\x41SSERTION_TYPE_CODE\x10\x02\"\xaf\x01\n\x0cLLMAssertion\x12\"\n\x14llm_evaluator_prompt\x18\x01 \x01(\tB\x04\xe2\x41\x01\x01\x12*\n\tproviders\x18\x02 \x03(\x0b\x32\x11.gateway.ProviderB\x04\xe2\x41\x01\x02\x12\x15\n\x07prompts\x18\x03 \x03(\tB\x04\xe2\x41\x01\x02\x12\x38\n\x10\x65valuate_options\x18\x04 \x01(\x0b\x32\x18.gateway.EvaluateOptionsB\x04\xe2\x41\x01\x01\"\xfb\x02\n\rCodeAssertion\x12\x16\n\x08language\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x12\n\x04\x63ode\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02\x12\x1d\n\x0f\x65xpected_output\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12>\n\x07options\x18\x04 \x01(\x0b\x32\'.gateway.CodeAssertion.ExecutionOptionsB\x04\xe2\x41\x01\x01\x1a\xde\x01\n\x10\x45xecutionOptions\x12#\n\ntimeout_ms\x18\x01 \x01(\x05\x42\x0f\xe2\x41\x01\x01\xbaH\x08\x1a\x06\x18\xe0\xa7\x12(\x00\x12\'\n\x0fmemory_limit_mb\x18\x02 \x01(\x05\x42\x0e\xe2\x41\x01\x01\xbaH\x07\x1a\x05\x18\x80\x08(\x00\x12L\n\x08\x65nv_vars\x18\x03 \x03(\x0b\x32\x34.gateway.CodeAssertion.ExecutionOptions.EnvVarsEntryB\x04\xe2\x41\x01\x01\x1a.\n\x0c\x45nvVarsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x83\x01\n\x08Provider\x12\n\n\x02id\x18\x01 \x01(\t\x12-\n\x06\x63onfig\x18\x02 \x03(\x0b\x32\x1d.gateway.Provider.ConfigEntry\x12\r\n\x05label\x18\x03 \x01(\t\x1a-\n\x0b\x43onfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"I\n\x0f\x45valuateOptions\x12\x17\n\x0fmax_concurrency\x18\x01 \x01(\x05\x12\x0e\n\x06repeat\x18\x02 \x01(\x05\x12\r\n\x05\x64\x65lay\x18\x03 \x01(\x05\"*\n\x14GetEvaluationRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"{\n\x17\x43reateEvaluationRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12-\n\nevaluation\x18\x02 \x01(\x0b\x32\x13.gateway.EvaluationB\x04\xe2\x41\x01\x02\x12\x1b\n\revaluation_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\"\x8f\x01\n\x16ListEvaluationsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"p\n\x17ListEvaluationsResponse\x12(\n\x0b\x65valuations\x18\x01 \x03(\x0b\x32\x13.gateway.Evaluation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"\x93\x01\n\x17UpdateEvaluationRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12-\n\nevaluation\x18\x02 \x01(\x0b\x32\x13.gateway.EvaluationB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"-\n\x17\x44\x65leteEvaluationRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"w\n\x15TestEvaluationRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12-\n\nevaluation\x18\x02 \x01(\x0b\x32\x13.gateway.EvaluationB\x04\xe2\x41\x01\x02\x12\x19\n\x0bsample_data\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02\"_\n\x19ValidateAssertionsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12,\n\nassertions\x18\x02 \x03(\x0b\x32\x12.gateway.AssertionB\x04\xe2\x41\x01\x02\"\xa4\x02\n\x1aValidateAssertionsResponse\x12\x0e\n\x06status\x18\x01 \x01(\t\x12Q\n\x10metric_to_errors\x18\x02 \x03(\x0b\x32\x37.gateway.ValidateAssertionsResponse.MetricToErrorsEntry\x1aq\n\x13MetricToErrorsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12I\n\x05value\x18\x02 \x01(\x0b\x32:.gateway.ValidateAssertionsResponse.ValidateAssertionError:\x02\x38\x01\x1a\x30\n\x16ValidateAssertionError\x12\x16\n\x0e\x65rror_messages\x18\x01 \x03(\t\"d\n\x18PreviewEvaluationRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x19\n\x0bsample_data\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02\x12\x19\n\x0bmax_samples\x18\x03 \x01(\x05\x42\x04\xe2\x41\x01\x01\"\xe8\x01\n\x17PreviewEvaluationResult\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0e\n\x06reason\x18\x02 \x01(\t\x12\x11\n\x05score\x18\x03 \x01(\x01\x42\x02\x18\x01\x12)\n\x08messages\x18\x04 \x03(\x0b\x32\x17.google.protobuf.Struct\x12>\n\x07metrics\x18\x05 \x03(\x0b\x32-.gateway.PreviewEvaluationResult.MetricsEntry\x1a.\n\x0cMetricsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\"\x7f\n\x19PreviewEvaluationResponse\x12\x31\n\x07results\x18\x01 \x03(\x0b\x32 .gateway.PreviewEvaluationResult\x12\x15\n\rtotal_samples\x18\x02 \x01(\x05\x12\x18\n\x10total_runtime_ms\x18\x03 \x01(\x03\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.evaluation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_EVALUATION'].fields_by_name['name']._loaded_options = None
  _globals['_EVALUATION'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_EVALUATION'].fields_by_name['create_time']._loaded_options = None
  _globals['_EVALUATION'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_EVALUATION'].fields_by_name['created_by']._loaded_options = None
  _globals['_EVALUATION'].fields_by_name['created_by']._serialized_options = b'\342A\002\003\005'
  _globals['_EVALUATION'].fields_by_name['status']._loaded_options = None
  _globals['_EVALUATION'].fields_by_name['status']._serialized_options = b'\342A\001\003'
  _globals['_EVALUATION'].fields_by_name['evaluation_type']._loaded_options = None
  _globals['_EVALUATION'].fields_by_name['evaluation_type']._serialized_options = b'\342A\001\002'
  _globals['_EVALUATION'].fields_by_name['description']._loaded_options = None
  _globals['_EVALUATION'].fields_by_name['description']._serialized_options = b'\342A\001\001'
  _globals['_EVALUATION'].fields_by_name['providers']._loaded_options = None
  _globals['_EVALUATION'].fields_by_name['providers']._serialized_options = b'\342A\001\002'
  _globals['_EVALUATION'].fields_by_name['assertions']._loaded_options = None
  _globals['_EVALUATION'].fields_by_name['assertions']._serialized_options = b'\342A\001\002'
  _globals['_EVALUATION'].fields_by_name['update_time']._loaded_options = None
  _globals['_EVALUATION'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_EVALUATION']._loaded_options = None
  _globals['_EVALUATION']._serialized_options = b'\030\001\352Ag\n\033api.fireworks.ai/Evaluation\022/accounts/{AccountId}/evaluations/{EvaluationId}*\013Evaluations2\nEvaluation\202\361\004\013\n\007Account\030\001'
  _globals['_ASSERTION'].fields_by_name['assertion_type']._loaded_options = None
  _globals['_ASSERTION'].fields_by_name['assertion_type']._serialized_options = b'\342A\001\002'
  _globals['_ASSERTION'].fields_by_name['metric_name']._loaded_options = None
  _globals['_ASSERTION'].fields_by_name['metric_name']._serialized_options = b'\342A\001\001'
  _globals['_LLMASSERTION'].fields_by_name['llm_evaluator_prompt']._loaded_options = None
  _globals['_LLMASSERTION'].fields_by_name['llm_evaluator_prompt']._serialized_options = b'\342A\001\001'
  _globals['_LLMASSERTION'].fields_by_name['providers']._loaded_options = None
  _globals['_LLMASSERTION'].fields_by_name['providers']._serialized_options = b'\342A\001\002'
  _globals['_LLMASSERTION'].fields_by_name['prompts']._loaded_options = None
  _globals['_LLMASSERTION'].fields_by_name['prompts']._serialized_options = b'\342A\001\002'
  _globals['_LLMASSERTION'].fields_by_name['evaluate_options']._loaded_options = None
  _globals['_LLMASSERTION'].fields_by_name['evaluate_options']._serialized_options = b'\342A\001\001'
  _globals['_CODEASSERTION_EXECUTIONOPTIONS_ENVVARSENTRY']._loaded_options = None
  _globals['_CODEASSERTION_EXECUTIONOPTIONS_ENVVARSENTRY']._serialized_options = b'8\001'
  _globals['_CODEASSERTION_EXECUTIONOPTIONS'].fields_by_name['timeout_ms']._loaded_options = None
  _globals['_CODEASSERTION_EXECUTIONOPTIONS'].fields_by_name['timeout_ms']._serialized_options = b'\342A\001\001\272H\010\032\006\030\340\247\022(\000'
  _globals['_CODEASSERTION_EXECUTIONOPTIONS'].fields_by_name['memory_limit_mb']._loaded_options = None
  _globals['_CODEASSERTION_EXECUTIONOPTIONS'].fields_by_name['memory_limit_mb']._serialized_options = b'\342A\001\001\272H\007\032\005\030\200\010(\000'
  _globals['_CODEASSERTION_EXECUTIONOPTIONS'].fields_by_name['env_vars']._loaded_options = None
  _globals['_CODEASSERTION_EXECUTIONOPTIONS'].fields_by_name['env_vars']._serialized_options = b'\342A\001\001'
  _globals['_CODEASSERTION'].fields_by_name['language']._loaded_options = None
  _globals['_CODEASSERTION'].fields_by_name['language']._serialized_options = b'\342A\001\002'
  _globals['_CODEASSERTION'].fields_by_name['code']._loaded_options = None
  _globals['_CODEASSERTION'].fields_by_name['code']._serialized_options = b'\342A\001\002'
  _globals['_CODEASSERTION'].fields_by_name['expected_output']._loaded_options = None
  _globals['_CODEASSERTION'].fields_by_name['expected_output']._serialized_options = b'\342A\001\001'
  _globals['_CODEASSERTION'].fields_by_name['options']._loaded_options = None
  _globals['_CODEASSERTION'].fields_by_name['options']._serialized_options = b'\342A\001\001'
  _globals['_PROVIDER_CONFIGENTRY']._loaded_options = None
  _globals['_PROVIDER_CONFIGENTRY']._serialized_options = b'8\001'
  _globals['_GETEVALUATIONREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETEVALUATIONREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_CREATEEVALUATIONREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEEVALUATIONREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEEVALUATIONREQUEST'].fields_by_name['evaluation']._loaded_options = None
  _globals['_CREATEEVALUATIONREQUEST'].fields_by_name['evaluation']._serialized_options = b'\342A\001\002'
  _globals['_CREATEEVALUATIONREQUEST'].fields_by_name['evaluation_id']._loaded_options = None
  _globals['_CREATEEVALUATIONREQUEST'].fields_by_name['evaluation_id']._serialized_options = b'\342A\001\001'
  _globals['_LISTEVALUATIONSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTEVALUATIONSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTEVALUATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTEVALUATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTEVALUATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTEVALUATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTEVALUATIONSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTEVALUATIONSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTEVALUATIONSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTEVALUATIONSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEEVALUATIONREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEEVALUATIONREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEEVALUATIONREQUEST'].fields_by_name['evaluation']._loaded_options = None
  _globals['_UPDATEEVALUATIONREQUEST'].fields_by_name['evaluation']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEEVALUATIONREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEEVALUATIONREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_DELETEEVALUATIONREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEEVALUATIONREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_TESTEVALUATIONREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_TESTEVALUATIONREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_TESTEVALUATIONREQUEST'].fields_by_name['evaluation']._loaded_options = None
  _globals['_TESTEVALUATIONREQUEST'].fields_by_name['evaluation']._serialized_options = b'\342A\001\002'
  _globals['_TESTEVALUATIONREQUEST'].fields_by_name['sample_data']._loaded_options = None
  _globals['_TESTEVALUATIONREQUEST'].fields_by_name['sample_data']._serialized_options = b'\342A\001\002'
  _globals['_VALIDATEASSERTIONSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_VALIDATEASSERTIONSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_VALIDATEASSERTIONSREQUEST'].fields_by_name['assertions']._loaded_options = None
  _globals['_VALIDATEASSERTIONSREQUEST'].fields_by_name['assertions']._serialized_options = b'\342A\001\002'
  _globals['_VALIDATEASSERTIONSRESPONSE_METRICTOERRORSENTRY']._loaded_options = None
  _globals['_VALIDATEASSERTIONSRESPONSE_METRICTOERRORSENTRY']._serialized_options = b'8\001'
  _globals['_PREVIEWEVALUATIONREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_PREVIEWEVALUATIONREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_PREVIEWEVALUATIONREQUEST'].fields_by_name['sample_data']._loaded_options = None
  _globals['_PREVIEWEVALUATIONREQUEST'].fields_by_name['sample_data']._serialized_options = b'\342A\001\002'
  _globals['_PREVIEWEVALUATIONREQUEST'].fields_by_name['max_samples']._loaded_options = None
  _globals['_PREVIEWEVALUATIONREQUEST'].fields_by_name['max_samples']._serialized_options = b'\342A\001\001'
  _globals['_PREVIEWEVALUATIONRESULT_METRICSENTRY']._loaded_options = None
  _globals['_PREVIEWEVALUATIONRESULT_METRICSENTRY']._serialized_options = b'8\001'
  _globals['_PREVIEWEVALUATIONRESULT'].fields_by_name['score']._loaded_options = None
  _globals['_PREVIEWEVALUATIONRESULT'].fields_by_name['score']._serialized_options = b'\030\001'
  _globals['_EVALUATION']._serialized_start=269
  _globals['_EVALUATION']._serialized_end=752
  _globals['_ASSERTION']._serialized_start=755
  _globals['_ASSERTION']._serialized_end=1049
  _globals['_ASSERTION_ASSERTIONTYPE']._serialized_start=953
  _globals['_ASSERTION_ASSERTIONTYPE']._serialized_end=1049
  _globals['_LLMASSERTION']._serialized_start=1052
  _globals['_LLMASSERTION']._serialized_end=1227
  _globals['_CODEASSERTION']._serialized_start=1230
  _globals['_CODEASSERTION']._serialized_end=1609
  _globals['_CODEASSERTION_EXECUTIONOPTIONS']._serialized_start=1387
  _globals['_CODEASSERTION_EXECUTIONOPTIONS']._serialized_end=1609
  _globals['_CODEASSERTION_EXECUTIONOPTIONS_ENVVARSENTRY']._serialized_start=1563
  _globals['_CODEASSERTION_EXECUTIONOPTIONS_ENVVARSENTRY']._serialized_end=1609
  _globals['_PROVIDER']._serialized_start=1612
  _globals['_PROVIDER']._serialized_end=1743
  _globals['_PROVIDER_CONFIGENTRY']._serialized_start=1698
  _globals['_PROVIDER_CONFIGENTRY']._serialized_end=1743
  _globals['_EVALUATEOPTIONS']._serialized_start=1745
  _globals['_EVALUATEOPTIONS']._serialized_end=1818
  _globals['_GETEVALUATIONREQUEST']._serialized_start=1820
  _globals['_GETEVALUATIONREQUEST']._serialized_end=1862
  _globals['_CREATEEVALUATIONREQUEST']._serialized_start=1864
  _globals['_CREATEEVALUATIONREQUEST']._serialized_end=1987
  _globals['_LISTEVALUATIONSREQUEST']._serialized_start=1990
  _globals['_LISTEVALUATIONSREQUEST']._serialized_end=2133
  _globals['_LISTEVALUATIONSRESPONSE']._serialized_start=2135
  _globals['_LISTEVALUATIONSRESPONSE']._serialized_end=2247
  _globals['_UPDATEEVALUATIONREQUEST']._serialized_start=2250
  _globals['_UPDATEEVALUATIONREQUEST']._serialized_end=2397
  _globals['_DELETEEVALUATIONREQUEST']._serialized_start=2399
  _globals['_DELETEEVALUATIONREQUEST']._serialized_end=2444
  _globals['_TESTEVALUATIONREQUEST']._serialized_start=2446
  _globals['_TESTEVALUATIONREQUEST']._serialized_end=2565
  _globals['_VALIDATEASSERTIONSREQUEST']._serialized_start=2567
  _globals['_VALIDATEASSERTIONSREQUEST']._serialized_end=2662
  _globals['_VALIDATEASSERTIONSRESPONSE']._serialized_start=2665
  _globals['_VALIDATEASSERTIONSRESPONSE']._serialized_end=2957
  _globals['_VALIDATEASSERTIONSRESPONSE_METRICTOERRORSENTRY']._serialized_start=2794
  _globals['_VALIDATEASSERTIONSRESPONSE_METRICTOERRORSENTRY']._serialized_end=2907
  _globals['_VALIDATEASSERTIONSRESPONSE_VALIDATEASSERTIONERROR']._serialized_start=2909
  _globals['_VALIDATEASSERTIONSRESPONSE_VALIDATEASSERTIONERROR']._serialized_end=2957
  _globals['_PREVIEWEVALUATIONREQUEST']._serialized_start=2959
  _globals['_PREVIEWEVALUATIONREQUEST']._serialized_end=3059
  _globals['_PREVIEWEVALUATIONRESULT']._serialized_start=3062
  _globals['_PREVIEWEVALUATIONRESULT']._serialized_end=3294
  _globals['_PREVIEWEVALUATIONRESULT_METRICSENTRY']._serialized_start=3248
  _globals['_PREVIEWEVALUATIONRESULT_METRICSENTRY']._serialized_end=3294
  _globals['_PREVIEWEVALUATIONRESPONSE']._serialized_start=3296
  _globals['_PREVIEWEVALUATIONRESPONSE']._serialized_end=3423
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/supervised_fine_tuning_job.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/supervised_fine_tuning_job.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from . import deployment_pb2 as gateway_dot_deployment__pb2
from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from . import wandb_pb2 as gateway_dot_wandb__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from ..google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(gateway/supervised_fine_tuning_job.proto\x12\x07gateway\x1a\x1b\x62uf/validate/validate.proto\x1a\x18gateway/deployment.proto\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x13gateway/wandb.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/api/visibility.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe1\x0e\n\x17SupervisedFineTuningJob\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x39\n\x0e\x63ompleted_time\x18\x17 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x15\n\x07\x64\x61taset\x18\x04 \x01(\tB\x04\xe2\x41\x01\x02\x12\'\n\x05state\x18\x05 \x01(\x0e\x32\x11.gateway.JobStateB\x05\xe2\x41\x02\x03\x05\x12&\n\x06status\x18\x06 \x01(\x0b\x32\x0f.gateway.StatusB\x05\xe2\x41\x02\x03\x05\x12\x19\n\ncreated_by\x18\x07 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0coutput_model\x18\x08 \x01(\tB\x04\xe2\x41\x01\x01\x12\x18\n\nbase_model\x18\t \x01(\tB\x04\xe2\x41\x01\x01\x12\x1d\n\x0fwarm_start_from\x18\n \x01(\tB\x04\xe2\x41\x01\x01\x12\x1c\n\x0ejinja_template\x18\x0b \x01(\tB\x04\xe2\x41\x01\x01\x12\x18\n\nearly_stop\x18\x0c \x01(\x08\x42\x04\xe2\x41\x01\x01\x12\x1d\n\x06\x65pochs\x18\r \x01(\x05\x42\r\xe2\x41\x01\x01\xbaH\x06\x1a\x04\x18\x64(\x00\x12*\n\rlearning_rate\x18\x0e \x01(\x02\x42\x13\xe2\x41\x01\x01\xbaH\x0c\n\n\x1d\xcd\xcc\xcc=-\x00\x00\x00\x00\x12\'\n\x12max_context_length\x18\x0f \x01(\x05\x42\x0b\xe2\x41\x01\x01\xbaH\x04\x1a\x02(\x00\x12 \n\tlora_rank\x18\x10 \x01(\x05\x42\r\xe2\x41\x01\x01\xbaH\x06\x1a\x04\x18 (\x00\x12q\n\x1b\x62\x61se_model_weight_precision\x18\x11 \x01(\x0e\x32\x30.gateway.SupervisedFineTuningJob.WeightPrecisionB\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x30\n\x0cwandb_config\x18\x12 \x01(\x0b\x32\x14.gateway.WandbConfigB\x04\xe2\x41\x01\x01\x12 \n\x12\x65valuation_dataset\x18\x13 \x01(\tB\x04\xe2\x41\x01\x01\x12N\n\x10\x61\x63\x63\x65lerator_type\x18\x14 \x01(\x0e\x32\x18.gateway.AcceleratorTypeB\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x35\n\x11\x61\x63\x63\x65lerator_count\x18\x15 \x01(\x05\x42\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x16\n\x08is_turbo\x18\x16 \x01(\x08\x42\x04\xe2\x41\x01\x01\x12 \n\x12\x65val_auto_carveout\x18\x18 \x01(\x08\x42\x04\xe2\x41\x01\x01\x12%\n\x06region\x18\x19 \x01(\x0e\x32\x0f.gateway.RegionB\x04\xe2\x41\x01\x01\x12\x35\n\x0bupdate_time\x18\x1a \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x12\x13\n\x05nodes\x18\x1b \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x1f\n\nbatch_size\x18\x1c \x01(\x05\x42\x0b\xe2\x41\x01\x01\xbaH\x04\x1a\x02(\x00\x12\x19\n\x0bmtp_enabled\x18\x1d \x01(\x08\x42\x04\xe2\x41\x01\x01\x12\"\n\x14mtp_num_draft_tokens\x18\x1e \x01(\x05\x42\x04\xe2\x41\x01\x01\x12#\n\x15mtp_freeze_base_model\x18\x1f \x01(\x08\x42\x04\xe2\x41\x01\x01\"T\n\x0fWeightPrecision\x12 \n\x1cWEIGHT_PRECISION_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x42\x46LOAT16\x10\x01\x12\x08\n\x04INT8\x10\x02\x12\x07\n\x03NF4\x10\x03:\xa5\x04\xea\x41\xa8\x01\n(api.fireworks.ai/SupervisedFineTuningJob\x12Iaccounts/{AccountId}/supervisedFineTuningJobs/{SupervisedFineTuningJobId}*\x18supervisedFineTuningJobs2\x17supervisedFineTuningJob\xbaH\xe6\x02\x1a\xb6\x01\n;supervised_fine_tuning_job.exactly_one_of_must_be_specified\x12>exactly one of base_model or warm_start_from must be specified\x1a\x37(this.base_model != \'\') != (this.warm_start_from != \'\')\x1a\xaa\x01\n<supervised_fine_tuning_job.batch_size_gte_max_context_length\x12>batch_size must be greater than or equal to max_context_length\x1a*this.batch_size >= this.max_context_length\x82\xf1\x04\x0b\n\x07\x41\x63\x63ount\x18\x01\"7\n!GetSupervisedFineTuningJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\xe0\x01\n$CreateSupervisedFineTuningJobRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12J\n\x1asupervised_fine_tuning_job\x18\x02 \x01(\x0b\x32 .gateway.SupervisedFineTuningJobB\x04\xe2\x41\x01\x02\x12)\n\x05\x64\x65\x62ug\x18\x03 \x01(\x08\x42\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12+\n\x1dsupervised_fine_tuning_job_id\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\"\x9c\x01\n#ListSupervisedFineTuningJobsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"\x9a\x01\n$ListSupervisedFineTuningJobsResponse\x12\x45\n\x1bsupervised_fine_tuning_jobs\x18\x01 \x03(\x0b\x32 .gateway.SupervisedFineTuningJob\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\":\n$DeleteSupervisedFineTuningJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.supervised_fine_tuning_job_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['name']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['display_name']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['create_time']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['completed_time']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['completed_time']._serialized_options = b'\342A\002\003\005'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['dataset']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['dataset']._serialized_options = b'\342A\001\002'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['state']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['status']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['created_by']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['created_by']._serialized_options = b'\342A\002\003\005'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['output_model']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['output_model']._serialized_options = b'\342A\001\001'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['base_model']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['base_model']._serialized_options = b'\342A\001\001'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['warm_start_from']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['warm_start_from']._serialized_options = b'\342A\001\001'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['jinja_template']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['jinja_template']._serialized_options = b'\342A\001\001'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['early_stop']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['early_stop']._serialized_options = b'\342A\001\001'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['epochs']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['epochs']._serialized_options = b'\342A\001\001\272H\006\032\004\030d(\000'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['learning_rate']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['learning_rate']._serialized_options = b'\342A\001\001\272H\014\n\n\035\315\314\314=-\000\000\000\000'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['max_context_length']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['max_context_length']._serialized_options = b'\342A\001\001\272H\004\032\002(\000'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['lora_rank']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['lora_rank']._serialized_options = b'\342A\001\001\272H\006\032\004\030 (\000'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['base_model_weight_precision']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['base_model_weight_precision']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['wandb_config']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['wandb_config']._serialized_options = b'\342A\001\001'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['evaluation_dataset']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['evaluation_dataset']._serialized_options = b'\342A\001\001'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['accelerator_type']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['accelerator_type']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['accelerator_count']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['accelerator_count']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['is_turbo']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['is_turbo']._serialized_options = b'\342A\001\001'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['eval_auto_carveout']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['eval_auto_carveout']._serialized_options = b'\342A\001\001'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['region']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['region']._serialized_options = b'\342A\001\001'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['update_time']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['nodes']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['nodes']._serialized_options = b'\342A\001\001'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['batch_size']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['batch_size']._serialized_options = b'\342A\001\001\272H\004\032\002(\000'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['mtp_enabled']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['mtp_enabled']._serialized_options = b'\342A\001\001'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['mtp_num_draft_tokens']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['mtp_num_draft_tokens']._serialized_options = b'\342A\001\001'
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['mtp_freeze_base_model']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB'].fields_by_name['mtp_freeze_base_model']._serialized_options = b'\342A\001\001'
  _globals['_SUPERVISEDFINETUNINGJOB']._loaded_options = None
  _globals['_SUPERVISEDFINETUNINGJOB']._serialized_options = b'\352A\250\001\n(api.fireworks.ai/SupervisedFineTuningJob\022Iaccounts/{AccountId}/supervisedFineTuningJobs/{SupervisedFineTuningJobId}*\030supervisedFineTuningJobs2\027supervisedFineTuningJob\272H\346\002\032\266\001\n;supervised_fine_tuning_job.exactly_one_of_must_be_specified\022>exactly one of base_model or warm_start_from must be specified\0327(this.base_model != \'\') != (this.warm_start_from != \'\')\032\252\001\n<supervised_fine_tuning_job.batch_size_gte_max_context_length\022>batch_size must be greater than or equal to max_context_length\032*this.batch_size >= this.max_context_length\202\361\004\013\n\007Account\030\001'
  _globals['_GETSUPERVISEDFINETUNINGJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETSUPERVISEDFINETUNINGJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_CREATESUPERVISEDFINETUNINGJOBREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATESUPERVISEDFINETUNINGJOBREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATESUPERVISEDFINETUNINGJOBREQUEST'].fields_by_name['supervised_fine_tuning_job']._loaded_options = None
  _globals['_CREATESUPERVISEDFINETUNINGJOBREQUEST'].fields_by_name['supervised_fine_tuning_job']._serialized_options = b'\342A\001\002'
  _globals['_CREATESUPERVISEDFINETUNINGJOBREQUEST'].fields_by_name['debug']._loaded_options = None
  _globals['_CREATESUPERVISEDFINETUNINGJOBREQUEST'].fields_by_name['debug']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_CREATESUPERVISEDFINETUNINGJOBREQUEST'].fields_by_name['supervised_fine_tuning_job_id']._loaded_options = None
  _globals['_CREATESUPERVISEDFINETUNINGJOBREQUEST'].fields_by_name['supervised_fine_tuning_job_id']._serialized_options = b'\342A\001\001'
  _globals['_LISTSUPERVISEDFINETUNINGJOBSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTSUPERVISEDFINETUNINGJOBSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTSUPERVISEDFINETUNINGJOBSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTSUPERVISEDFINETUNINGJOBSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTSUPERVISEDFINETUNINGJOBSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTSUPERVISEDFINETUNINGJOBSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTSUPERVISEDFINETUNINGJOBSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTSUPERVISEDFINETUNINGJOBSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTSUPERVISEDFINETUNINGJOBSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTSUPERVISEDFINETUNINGJOBSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_DELETESUPERVISEDFINETUNINGJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETESUPERVISEDFINETUNINGJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_SUPERVISEDFINETUNINGJOB']._serialized_start=297
  _globals['_SUPERVISEDFINETUNINGJOB']._serialized_end=2186
  _globals['_SUPERVISEDFINETUNINGJOB_WEIGHTPRECISION']._serialized_start=1550
  _globals['_SUPERVISEDFINETUNINGJOB_WEIGHTPRECISION']._serialized_end=1634
  _globals['_GETSUPERVISEDFINETUNINGJOBREQUEST']._serialized_start=2188
  _globals['_GETSUPERVISEDFINETUNINGJOBREQUEST']._serialized_end=2243
  _globals['_CREATESUPERVISEDFINETUNINGJOBREQUEST']._serialized_start=2246
  _globals['_CREATESUPERVISEDFINETUNINGJOBREQUEST']._serialized_end=2470
  _globals['_LISTSUPERVISEDFINETUNINGJOBSREQUEST']._serialized_start=2473
  _globals['_LISTSUPERVISEDFINETUNINGJOBSREQUEST']._serialized_end=2629
  _globals['_LISTSUPERVISEDFINETUNINGJOBSRESPONSE']._serialized_start=2632
  _globals['_LISTSUPERVISEDFINETUNINGJOBSRESPONSE']._serialized_end=2786
  _globals['_DELETESUPERVISEDFINETUNINGJOBREQUEST']._serialized_start=2788
  _globals['_DELETESUPERVISEDFINETUNINGJOBREQUEST']._serialized_end=2846
# @@protoc_insertion_point(module_scope)



from . import options_pb2 as _options_pb2
from ..google.api import resource_pb2 as _resource_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from ..google.type import date_pb2 as _date_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class OuterEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    OUTER_ENUM_UNSPECIFIED: _ClassVar[OuterEnum]
    ONE: _ClassVar[OuterEnum]
OUTER_ENUM_UNSPECIFIED: OuterEnum
ONE: OuterEnum

class TestResource(_message.Message):
    __slots__ = ("name", "f2", "f3", "f4", "f5", "f6", "f7", "f8", "f9", "f10", "f11", "f12", "f13", "f14", "f15", "f16", "f18", "f19", "f20", "f21", "f22")
    class InnerEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        INNER_ENUM_UNSPECIFIED: _ClassVar[TestResource.InnerEnum]
        ONE: _ClassVar[TestResource.InnerEnum]
    INNER_ENUM_UNSPECIFIED: TestResource.InnerEnum
    ONE: TestResource.InnerEnum
    class InnerMessage(_message.Message):
        __slots__ = ("foo",)
        FOO_FIELD_NUMBER: _ClassVar[int]
        foo: str
        def __init__(self, foo: _Optional[str] = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    F2_FIELD_NUMBER: _ClassVar[int]
    F3_FIELD_NUMBER: _ClassVar[int]
    F4_FIELD_NUMBER: _ClassVar[int]
    F5_FIELD_NUMBER: _ClassVar[int]
    F6_FIELD_NUMBER: _ClassVar[int]
    F7_FIELD_NUMBER: _ClassVar[int]
    F8_FIELD_NUMBER: _ClassVar[int]
    F9_FIELD_NUMBER: _ClassVar[int]
    F10_FIELD_NUMBER: _ClassVar[int]
    F11_FIELD_NUMBER: _ClassVar[int]
    F12_FIELD_NUMBER: _ClassVar[int]
    F13_FIELD_NUMBER: _ClassVar[int]
    F14_FIELD_NUMBER: _ClassVar[int]
    F15_FIELD_NUMBER: _ClassVar[int]
    F16_FIELD_NUMBER: _ClassVar[int]
    F18_FIELD_NUMBER: _ClassVar[int]
    F19_FIELD_NUMBER: _ClassVar[int]
    F20_FIELD_NUMBER: _ClassVar[int]
    F21_FIELD_NUMBER: _ClassVar[int]
    F22_FIELD_NUMBER: _ClassVar[int]
    name: str
    f2: float
    f3: float
    f4: int
    f5: int
    f6: int
    f7: int
    f8: int
    f9: int
    f10: int
    f11: int
    f12: int
    f13: int
    f14: bool
    f15: str
    f16: _timestamp_pb2.Timestamp
    f18: TestResource.InnerEnum
    f19: OuterEnum
    f20: TestResource.InnerMessage
    f21: OuterMessage
    f22: _date_pb2.Date
    def __init__(self, name: _Optional[str] = ..., f2: _Optional[float] = ..., f3: _Optional[float] = ..., f4: _Optional[int] = ..., f5: _Optional[int] = ..., f6: _Optional[int] = ..., f7: _Optional[int] = ..., f8: _Optional[int] = ..., f9: _Optional[int] = ..., f10: _Optional[int] = ..., f11: _Optional[int] = ..., f12: _Optional[int] = ..., f13: _Optional[int] = ..., f14: bool = ..., f15: _Optional[str] = ..., f16: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., f18: _Optional[_Union[TestResource.InnerEnum, str]] = ..., f19: _Optional[_Union[OuterEnum, str]] = ..., f20: _Optional[_Union[TestResource.InnerMessage, _Mapping]] = ..., f21: _Optional[_Union[OuterMessage, _Mapping]] = ..., f22: _Optional[_Union[_date_pb2.Date, _Mapping]] = ...) -> None: ...

class OuterMessage(_message.Message):
    __slots__ = ("bar",)
    BAR_FIELD_NUMBER: _ClassVar[int]
    bar: str
    def __init__(self, bar: _Optional[str] = ...) -> None: ...



from . import options_pb2 as _options_pb2
from ..google.api import field_behavior_pb2 as _field_behavior_pb2
from ..google.api import resource_pb2 as _resource_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AlertRule(_message.Message):
    __slots__ = ("name", "alert_rule_configuration", "threshold", "duration", "enabled", "filters", "notification_channels", "create_time", "update_time")
    NAME_FIELD_NUMBER: _ClassVar[int]
    ALERT_RULE_CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    DURATION_FIELD_NUMBER: _ClassVar[int]
    ENABLED_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    NOTIFICATION_CHANNELS_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    name: str
    alert_rule_configuration: str
    threshold: float
    duration: str
    enabled: bool
    filters: _containers.RepeatedCompositeFieldContainer[Filter]
    notification_channels: _containers.RepeatedScalarFieldContainer[str]
    create_time: _timestamp_pb2.Timestamp
    update_time: _timestamp_pb2.Timestamp
    def __init__(self, name: _Optional[str] = ..., alert_rule_configuration: _Optional[str] = ..., threshold: _Optional[float] = ..., duration: _Optional[str] = ..., enabled: bool = ..., filters: _Optional[_Iterable[_Union[Filter, _Mapping]]] = ..., notification_channels: _Optional[_Iterable[str]] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., update_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class Filter(_message.Message):
    __slots__ = ("key", "value", "operator")
    class Operator(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        OPERATOR_UNSPECIFIED: _ClassVar[Filter.Operator]
        EQUAL: _ClassVar[Filter.Operator]
        NOT_EQUAL: _ClassVar[Filter.Operator]
        EQUAL_REGEX: _ClassVar[Filter.Operator]
        NOT_EQUAL_REGEX: _ClassVar[Filter.Operator]
        CONTAINS: _ClassVar[Filter.Operator]
        NOT_CONTAINS: _ClassVar[Filter.Operator]
    OPERATOR_UNSPECIFIED: Filter.Operator
    EQUAL: Filter.Operator
    NOT_EQUAL: Filter.Operator
    EQUAL_REGEX: Filter.Operator
    NOT_EQUAL_REGEX: Filter.Operator
    CONTAINS: Filter.Operator
    NOT_CONTAINS: Filter.Operator
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    OPERATOR_FIELD_NUMBER: _ClassVar[int]
    key: str
    value: str
    operator: Filter.Operator
    def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ..., operator: _Optional[_Union[Filter.Operator, str]] = ...) -> None: ...

class AlertRuleConfiguration(_message.Message):
    __slots__ = ("name", "kind", "monitoring_policy_configuration", "create_time", "update_time")
    class Kind(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        KIND_UNSPECIFIED: _ClassVar[AlertRuleConfiguration.Kind]
        MISSING_REPLICAS: _ClassVar[AlertRuleConfiguration.Kind]
        HIGH_ERROR_COUNT: _ClassVar[AlertRuleConfiguration.Kind]
        HIGH_PERPLEXITY_OUTPUT: _ClassVar[AlertRuleConfiguration.Kind]
    KIND_UNSPECIFIED: AlertRuleConfiguration.Kind
    MISSING_REPLICAS: AlertRuleConfiguration.Kind
    HIGH_ERROR_COUNT: AlertRuleConfiguration.Kind
    HIGH_PERPLEXITY_OUTPUT: AlertRuleConfiguration.Kind
    class MonitoringPolicyConfiguration(_message.Message):
        __slots__ = ("documentation", "display_name", "combiner", "aligner", "comparison", "alignment_period", "expression", "severity", "notification_channels", "deployment_label_key")
        DOCUMENTATION_FIELD_NUMBER: _ClassVar[int]
        DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
        COMBINER_FIELD_NUMBER: _ClassVar[int]
        ALIGNER_FIELD_NUMBER: _ClassVar[int]
        COMPARISON_FIELD_NUMBER: _ClassVar[int]
        ALIGNMENT_PERIOD_FIELD_NUMBER: _ClassVar[int]
        EXPRESSION_FIELD_NUMBER: _ClassVar[int]
        SEVERITY_FIELD_NUMBER: _ClassVar[int]
        NOTIFICATION_CHANNELS_FIELD_NUMBER: _ClassVar[int]
        DEPLOYMENT_LABEL_KEY_FIELD_NUMBER: _ClassVar[int]
        documentation: str
        display_name: str
        combiner: str
        aligner: str
        comparison: str
        alignment_period: str
        expression: str
        severity: str
        notification_channels: _containers.RepeatedScalarFieldContainer[str]
        deployment_label_key: str
        def __init__(self, documentation: _Optional[str] = ..., display_name: _Optional[str] = ..., combiner: _Optional[str] = ..., aligner: _Optional[str] = ..., comparison: _Optional[str] = ..., alignment_period: _Optional[str] = ..., expression: _Optional[str] = ..., severity: _Optional[str] = ..., notification_channels: _Optional[_Iterable[str]] = ..., deployment_label_key: _Optional[str] = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    KIND_FIELD_NUMBER: _ClassVar[int]
    MONITORING_POLICY_CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    name: str
    kind: AlertRuleConfiguration.Kind
    monitoring_policy_configuration: AlertRuleConfiguration.MonitoringPolicyConfiguration
    create_time: _timestamp_pb2.Timestamp
    update_time: _timestamp_pb2.Timestamp
    def __init__(self, name: _Optional[str] = ..., kind: _Optional[_Union[AlertRuleConfiguration.Kind, str]] = ..., monitoring_policy_configuration: _Optional[_Union[AlertRuleConfiguration.MonitoringPolicyConfiguration, _Mapping]] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., update_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/fine_tuning_job.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/fine_tuning_job.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from ..google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dgateway/fine_tuning_job.proto\x12\x07gateway\x1a\x1b\x62uf/validate/validate.proto\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/api/visibility.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x99\x18\n\rFineTuningJob\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x32\n\x05state\x18\x04 \x01(\x0e\x32\x1c.gateway.FineTuningJob.StateB\x05\xe2\x41\x02\x03\x05\x12\x15\n\x07\x64\x61taset\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\x12\x30\n\x08\x64\x61tasets\x18\x1d \x03(\x0b\x32\x1e.gateway.FineTuningJob.Dataset\x12&\n\x06status\x18\t \x01(\x0b\x32\x0f.gateway.StatusB\x05\xe2\x41\x02\x03\x05\x12\x19\n\ncreated_by\x18\n \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1f\n\x11\x63ontainer_version\x18\x0b \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08model_id\x18\r \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\nlegacy_job\x18& \x01(\x0b\x32 .gateway.FineTuningJob.LegacyJobH\x00\x12@\n\x0ftext_completion\x18\x0f \x01(\x0b\x32%.gateway.FineTuningJob.TextCompletionH\x00\x12H\n\x13text_classification\x18\x10 \x01(\x0b\x32).gateway.FineTuningJob.TextClassificationH\x00\x12;\n\x0c\x63onversation\x18\x17 \x01(\x0b\x32#.gateway.FineTuningJob.ConversationH\x00\x12\x45\n\x10\x64raft_model_data\x18  \x01(\x0b\x32%.gateway.FineTuningJob.DraftModelDataB\x02\x18\x01H\x00\x12<\n\x0b\x64raft_model\x18\x18 \x01(\x0b\x32!.gateway.FineTuningJob.DraftModelB\x02\x18\x01H\x00\x12\x31\n\x05genie\x18\x1b \x01(\x0b\x32\x1c.gateway.FineTuningJob.GenieB\x02\x18\x01H\x00\x12\x18\n\nbase_model\x18\x11 \x01(\tB\x04\xe2\x41\x01\x01\x12\x1e\n\x0fwarm_start_from\x18\" \x01(\tB\x05\xe2\x41\x02\x03\x05\x12.\n\nearly_stop\x18. \x01(\x08\x42\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12+\n\x06\x65pochs\x18\x12 \x01(\x01\x42\x1b\xe2\x41\x01\x01\xbaH\x14\x12\x12\x19\x00\x00\x00\x00\x00\x00Y@)\x00\x00\x00\x00\x00\x00\x00\x00\x12\x32\n\rlearning_rate\x18\x13 \x01(\x01\x42\x1b\xe2\x41\x01\x01\xbaH\x14\x12\x12\x19\x00\x00\x00\x00\x00\x00\xf0?)\x00\x00\x00\x00\x00\x00\x00\x00\x12\x35\n\x11lr_scheduler_type\x18, \x01(\tB\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x37\n\x0cwarmup_steps\x18- \x01(\x05\x42!\xe2\x41\x01\x01\xbaH\x04\x1a\x02(\x00\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x38\n\nlora_alpha\x18* \x01(\x05\x42$\xe2\x41\x01\x01\xbaH\x07\x1a\x05\x18\x80\x08(\x00\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12 \n\tlora_rank\x18\x19 \x01(\x05\x42\r\xe2\x41\x01\x01\xbaH\x06\x1a\x04\x18 (\x00\x12!\n\x13lora_target_modules\x18+ \x03(\tB\x04\xe2\x41\x01\x01\x12\"\n\nbatch_size\x18\x1a \x01(\x05\x42\x0e\xe2\x41\x01\x01\xbaH\x07\x1a\x05\x18\x80\x08(\x00\x12%\n\x10micro_batch_size\x18\' \x01(\x05\x42\x0b\xe2\x41\x01\x01\xbaH\x04\x1a\x02(\x00\x12\x18\n\nmask_token\x18# \x01(\tB\x04\xe2\x41\x01\x01\x12\x17\n\tpad_token\x18$ \x01(\tB\x04\xe2\x41\x01\x01\x12\x38\n\rcutoff_length\x18% \x01(\x05\x42!\xe2\x41\x01\x01\xbaH\x04\x1a\x02(\x00\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x18\n\twandb_url\x18\x0e \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0cwandb_entity\x18\x14 \x01(\tB\x04\xe2\x41\x01\x01\x12\x1c\n\rwandb_api_key\x18\x15 \x01(\tB\x05\xe2\x41\x02\x01\x04\x12\x1b\n\rwandb_project\x18\x16 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\nevaluation\x18\x1e \x01(\x08\x42\x02\x18\x01\x12\x1e\n\x10\x65valuation_split\x18\x1f \x01(\x01\x42\x04\xe2\x41\x01\x01\x12 \n\x12\x65valuation_dataset\x18) \x01(\tB\x04\xe2\x41\x01\x01\x12\x1c\n\x0e\x64\x65pendent_jobs\x18! \x03(\tB\x04\xe2\x41\x01\x01\x1a!\n\x07\x44\x61taset\x12\x16\n\x07\x64\x61taset\x18\x01 \x01(\tB\x05\xe2\x41\x02\x05\x01\x1a\x0b\n\tLegacyJob\x1aM\n\x0eTextCompletion\x12\x1c\n\x0einput_template\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x1d\n\x0foutput_template\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02\x1a=\n\x12TextClassification\x12\x12\n\x04text\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x13\n\x05label\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02\x1ao\n\x0e\x44raftModelData\x12\x1d\n\x0f\x64\x65ployment_name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x1c\n\x0ejinja_template\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12 \n\x12\x63leanup_deployment\x18\x1e \x01(\x08\x42\x04\xe2\x41\x01\x01\x1a\x0c\n\nDraftModel\x1a,\n\x0c\x43onversation\x12\x1c\n\x0ejinja_template\x18\x01 \x01(\tB\x04\xe2\x41\x01\x01\x1a(\n\x05Genie\x12\x1b\n\rpipeline_name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02:\x02\x18\x01\"o\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\x0b\n\x07RUNNING\x10\x03\x12\r\n\tCOMPLETED\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05\x12\x0c\n\x08\x44\x45LETING\x10\x06:\x83\x07\xea\x41v\n\x1e\x61pi.fireworks.ai/FineTuningJob\x12\x35\x61\x63\x63ounts/{AccountId}/fineTuningJobs/{FineTuningJobId}*\x0e\x66ineTuningJobs2\rfineTuningJob\xbaH\xf7\x05\x1a\xb2\x01\n-fine_tuning_job.wandb_entity.requires_api_key\x12Hwandb_api_key must be specified if and only if wandb_entity is specified\x1a\x37(this.wandb_entity == \'\') == (this.wandb_api_key == \'\')\x1a\xb2\x01\n-fine_tuning_job.wandb_entity.requires_project\x12Hwandb_project must be specified if and only if wandb_entity is specified\x1a\x37(this.wandb_entity == \'\') == (this.wandb_project == \'\')\x1a\xab\x01\n0fine_tuning_job.exactly_one_of_must_be_specified\x12>exactly one of base_model or warm_start_from must be specified\x1a\x37(this.base_model != \'\') != (this.warm_start_from != \'\')\x1a\xdc\x01\n&fine_tuning_job.evaluation_split_range\x12Sevaluation_split must be between 0 and 0.5 when evaluation_dataset is not specified\x1a]this.evaluation_dataset != \'\' || (this.evaluation_split >= 0 && this.evaluation_split <= 0.5)\x82\xf1\x04\x0b\n\x07\x41\x63\x63ount\x18\x01\x42\x06\n\x04kind\"-\n\x17GetFineTuningJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\xd7\x01\n\x1a\x43reateFineTuningJobRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x35\n\x0f\x66ine_tuning_job\x18\x02 \x01(\x0b\x32\x16.gateway.FineTuningJobB\x04\xe2\x41\x01\x02\x12\x13\n\x05\x64\x65\x62ug\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01\x12 \n\x12\x66ine_tuning_job_id\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x35\n\x0bupdate_time\x18/ \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\"\x92\x01\n\x19ListFineTuningJobsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"{\n\x1aListFineTuningJobsResponse\x12\x30\n\x10\x66ine_tuning_jobs\x18\x01 \x03(\x0b\x32\x16.gateway.FineTuningJob\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"\x8a\x01\n\x1aUpdateFineTuningJobRequest\x12\x35\n\x0f\x66ine_tuning_job\x18\x01 \x01(\x0b\x32\x16.gateway.FineTuningJobB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"0\n\x1a\x44\x65leteFineTuningJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.fine_tuning_job_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_FINETUNINGJOB_DATASET'].fields_by_name['dataset']._loaded_options = None
  _globals['_FINETUNINGJOB_DATASET'].fields_by_name['dataset']._serialized_options = b'\342A\002\005\001'
  _globals['_FINETUNINGJOB_TEXTCOMPLETION'].fields_by_name['input_template']._loaded_options = None
  _globals['_FINETUNINGJOB_TEXTCOMPLETION'].fields_by_name['input_template']._serialized_options = b'\342A\001\002'
  _globals['_FINETUNINGJOB_TEXTCOMPLETION'].fields_by_name['output_template']._loaded_options = None
  _globals['_FINETUNINGJOB_TEXTCOMPLETION'].fields_by_name['output_template']._serialized_options = b'\342A\001\002'
  _globals['_FINETUNINGJOB_TEXTCLASSIFICATION'].fields_by_name['text']._loaded_options = None
  _globals['_FINETUNINGJOB_TEXTCLASSIFICATION'].fields_by_name['text']._serialized_options = b'\342A\001\002'
  _globals['_FINETUNINGJOB_TEXTCLASSIFICATION'].fields_by_name['label']._loaded_options = None
  _globals['_FINETUNINGJOB_TEXTCLASSIFICATION'].fields_by_name['label']._serialized_options = b'\342A\001\002'
  _globals['_FINETUNINGJOB_DRAFTMODELDATA'].fields_by_name['deployment_name']._loaded_options = None
  _globals['_FINETUNINGJOB_DRAFTMODELDATA'].fields_by_name['deployment_name']._serialized_options = b'\342A\001\002'
  _globals['_FINETUNINGJOB_DRAFTMODELDATA'].fields_by_name['jinja_template']._loaded_options = None
  _globals['_FINETUNINGJOB_DRAFTMODELDATA'].fields_by_name['jinja_template']._serialized_options = b'\342A\001\001'
  _globals['_FINETUNINGJOB_DRAFTMODELDATA'].fields_by_name['cleanup_deployment']._loaded_options = None
  _globals['_FINETUNINGJOB_DRAFTMODELDATA'].fields_by_name['cleanup_deployment']._serialized_options = b'\342A\001\001'
  _globals['_FINETUNINGJOB_CONVERSATION'].fields_by_name['jinja_template']._loaded_options = None
  _globals['_FINETUNINGJOB_CONVERSATION'].fields_by_name['jinja_template']._serialized_options = b'\342A\001\001'
  _globals['_FINETUNINGJOB_GENIE'].fields_by_name['pipeline_name']._loaded_options = None
  _globals['_FINETUNINGJOB_GENIE'].fields_by_name['pipeline_name']._serialized_options = b'\342A\001\002'
  _globals['_FINETUNINGJOB_GENIE']._loaded_options = None
  _globals['_FINETUNINGJOB_GENIE']._serialized_options = b'\030\001'
  _globals['_FINETUNINGJOB'].fields_by_name['name']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_FINETUNINGJOB'].fields_by_name['display_name']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_FINETUNINGJOB'].fields_by_name['create_time']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_FINETUNINGJOB'].fields_by_name['state']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_FINETUNINGJOB'].fields_by_name['dataset']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['dataset']._serialized_options = b'\342A\001\001'
  _globals['_FINETUNINGJOB'].fields_by_name['status']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_FINETUNINGJOB'].fields_by_name['created_by']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['created_by']._serialized_options = b'\342A\002\003\005'
  _globals['_FINETUNINGJOB'].fields_by_name['container_version']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['container_version']._serialized_options = b'\342A\001\001'
  _globals['_FINETUNINGJOB'].fields_by_name['model_id']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['model_id']._serialized_options = b'\342A\001\001'
  _globals['_FINETUNINGJOB'].fields_by_name['draft_model_data']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['draft_model_data']._serialized_options = b'\030\001'
  _globals['_FINETUNINGJOB'].fields_by_name['draft_model']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['draft_model']._serialized_options = b'\030\001'
  _globals['_FINETUNINGJOB'].fields_by_name['genie']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['genie']._serialized_options = b'\030\001'
  _globals['_FINETUNINGJOB'].fields_by_name['base_model']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['base_model']._serialized_options = b'\342A\001\001'
  _globals['_FINETUNINGJOB'].fields_by_name['warm_start_from']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['warm_start_from']._serialized_options = b'\342A\002\003\005'
  _globals['_FINETUNINGJOB'].fields_by_name['early_stop']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['early_stop']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_FINETUNINGJOB'].fields_by_name['epochs']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['epochs']._serialized_options = b'\342A\001\001\272H\024\022\022\031\000\000\000\000\000\000Y@)\000\000\000\000\000\000\000\000'
  _globals['_FINETUNINGJOB'].fields_by_name['learning_rate']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['learning_rate']._serialized_options = b'\342A\001\001\272H\024\022\022\031\000\000\000\000\000\000\360?)\000\000\000\000\000\000\000\000'
  _globals['_FINETUNINGJOB'].fields_by_name['lr_scheduler_type']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['lr_scheduler_type']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_FINETUNINGJOB'].fields_by_name['warmup_steps']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['warmup_steps']._serialized_options = b'\342A\001\001\272H\004\032\002(\000\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_FINETUNINGJOB'].fields_by_name['lora_alpha']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['lora_alpha']._serialized_options = b'\342A\001\001\272H\007\032\005\030\200\010(\000\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_FINETUNINGJOB'].fields_by_name['lora_rank']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['lora_rank']._serialized_options = b'\342A\001\001\272H\006\032\004\030 (\000'
  _globals['_FINETUNINGJOB'].fields_by_name['lora_target_modules']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['lora_target_modules']._serialized_options = b'\342A\001\001'
  _globals['_FINETUNINGJOB'].fields_by_name['batch_size']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['batch_size']._serialized_options = b'\342A\001\001\272H\007\032\005\030\200\010(\000'
  _globals['_FINETUNINGJOB'].fields_by_name['micro_batch_size']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['micro_batch_size']._serialized_options = b'\342A\001\001\272H\004\032\002(\000'
  _globals['_FINETUNINGJOB'].fields_by_name['mask_token']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['mask_token']._serialized_options = b'\342A\001\001'
  _globals['_FINETUNINGJOB'].fields_by_name['pad_token']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['pad_token']._serialized_options = b'\342A\001\001'
  _globals['_FINETUNINGJOB'].fields_by_name['cutoff_length']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['cutoff_length']._serialized_options = b'\342A\001\001\272H\004\032\002(\000\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_FINETUNINGJOB'].fields_by_name['wandb_url']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['wandb_url']._serialized_options = b'\342A\002\003\005'
  _globals['_FINETUNINGJOB'].fields_by_name['wandb_entity']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['wandb_entity']._serialized_options = b'\342A\001\001'
  _globals['_FINETUNINGJOB'].fields_by_name['wandb_api_key']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['wandb_api_key']._serialized_options = b'\342A\002\001\004'
  _globals['_FINETUNINGJOB'].fields_by_name['wandb_project']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['wandb_project']._serialized_options = b'\342A\001\001'
  _globals['_FINETUNINGJOB'].fields_by_name['evaluation']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['evaluation']._serialized_options = b'\030\001'
  _globals['_FINETUNINGJOB'].fields_by_name['evaluation_split']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['evaluation_split']._serialized_options = b'\342A\001\001'
  _globals['_FINETUNINGJOB'].fields_by_name['evaluation_dataset']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['evaluation_dataset']._serialized_options = b'\342A\001\001'
  _globals['_FINETUNINGJOB'].fields_by_name['dependent_jobs']._loaded_options = None
  _globals['_FINETUNINGJOB'].fields_by_name['dependent_jobs']._serialized_options = b'\342A\001\001'
  _globals['_FINETUNINGJOB']._loaded_options = None
  _globals['_FINETUNINGJOB']._serialized_options = b'\352Av\n\036api.fireworks.ai/FineTuningJob\0225accounts/{AccountId}/fineTuningJobs/{FineTuningJobId}*\016fineTuningJobs2\rfineTuningJob\272H\367\005\032\262\001\n-fine_tuning_job.wandb_entity.requires_api_key\022Hwandb_api_key must be specified if and only if wandb_entity is specified\0327(this.wandb_entity == \'\') == (this.wandb_api_key == \'\')\032\262\001\n-fine_tuning_job.wandb_entity.requires_project\022Hwandb_project must be specified if and only if wandb_entity is specified\0327(this.wandb_entity == \'\') == (this.wandb_project == \'\')\032\253\001\n0fine_tuning_job.exactly_one_of_must_be_specified\022>exactly one of base_model or warm_start_from must be specified\0327(this.base_model != \'\') != (this.warm_start_from != \'\')\032\334\001\n&fine_tuning_job.evaluation_split_range\022Sevaluation_split must be between 0 and 0.5 when evaluation_dataset is not specified\032]this.evaluation_dataset != \'\' || (this.evaluation_split >= 0 && this.evaluation_split <= 0.5)\202\361\004\013\n\007Account\030\001'
  _globals['_GETFINETUNINGJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETFINETUNINGJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_CREATEFINETUNINGJOBREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEFINETUNINGJOBREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEFINETUNINGJOBREQUEST'].fields_by_name['fine_tuning_job']._loaded_options = None
  _globals['_CREATEFINETUNINGJOBREQUEST'].fields_by_name['fine_tuning_job']._serialized_options = b'\342A\001\002'
  _globals['_CREATEFINETUNINGJOBREQUEST'].fields_by_name['debug']._loaded_options = None
  _globals['_CREATEFINETUNINGJOBREQUEST'].fields_by_name['debug']._serialized_options = b'\342A\001\001'
  _globals['_CREATEFINETUNINGJOBREQUEST'].fields_by_name['fine_tuning_job_id']._loaded_options = None
  _globals['_CREATEFINETUNINGJOBREQUEST'].fields_by_name['fine_tuning_job_id']._serialized_options = b'\342A\001\001'
  _globals['_CREATEFINETUNINGJOBREQUEST'].fields_by_name['update_time']._loaded_options = None
  _globals['_CREATEFINETUNINGJOBREQUEST'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_LISTFINETUNINGJOBSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTFINETUNINGJOBSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTFINETUNINGJOBSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTFINETUNINGJOBSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTFINETUNINGJOBSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTFINETUNINGJOBSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTFINETUNINGJOBSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTFINETUNINGJOBSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTFINETUNINGJOBSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTFINETUNINGJOBSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEFINETUNINGJOBREQUEST'].fields_by_name['fine_tuning_job']._loaded_options = None
  _globals['_UPDATEFINETUNINGJOBREQUEST'].fields_by_name['fine_tuning_job']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEFINETUNINGJOBREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEFINETUNINGJOBREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_DELETEFINETUNINGJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEFINETUNINGJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_FINETUNINGJOB']._serialized_start=273
  _globals['_FINETUNINGJOB']._serialized_end=3370
  _globals['_FINETUNINGJOB_DATASET']._serialized_start=1944
  _globals['_FINETUNINGJOB_DATASET']._serialized_end=1977
  _globals['_FINETUNINGJOB_LEGACYJOB']._serialized_start=1979
  _globals['_FINETUNINGJOB_LEGACYJOB']._serialized_end=1990
  _globals['_FINETUNINGJOB_TEXTCOMPLETION']._serialized_start=1992
  _globals['_FINETUNINGJOB_TEXTCOMPLETION']._serialized_end=2069
  _globals['_FINETUNINGJOB_TEXTCLASSIFICATION']._serialized_start=2071
  _globals['_FINETUNINGJOB_TEXTCLASSIFICATION']._serialized_end=2132
  _globals['_FINETUNINGJOB_DRAFTMODELDATA']._serialized_start=2134
  _globals['_FINETUNINGJOB_DRAFTMODELDATA']._serialized_end=2245
  _globals['_FINETUNINGJOB_DRAFTMODEL']._serialized_start=2247
  _globals['_FINETUNINGJOB_DRAFTMODEL']._serialized_end=2259
  _globals['_FINETUNINGJOB_CONVERSATION']._serialized_start=2261
  _globals['_FINETUNINGJOB_CONVERSATION']._serialized_end=2305
  _globals['_FINETUNINGJOB_GENIE']._serialized_start=2307
  _globals['_FINETUNINGJOB_GENIE']._serialized_end=2347
  _globals['_FINETUNINGJOB_STATE']._serialized_start=2349
  _globals['_FINETUNINGJOB_STATE']._serialized_end=2460
  _globals['_GETFINETUNINGJOBREQUEST']._serialized_start=3372
  _globals['_GETFINETUNINGJOBREQUEST']._serialized_end=3417
  _globals['_CREATEFINETUNINGJOBREQUEST']._serialized_start=3420
  _globals['_CREATEFINETUNINGJOBREQUEST']._serialized_end=3635
  _globals['_LISTFINETUNINGJOBSREQUEST']._serialized_start=3638
  _globals['_LISTFINETUNINGJOBSREQUEST']._serialized_end=3784
  _globals['_LISTFINETUNINGJOBSRESPONSE']._serialized_start=3786
  _globals['_LISTFINETUNINGJOBSRESPONSE']._serialized_end=3909
  _globals['_UPDATEFINETUNINGJOBREQUEST']._serialized_start=3912
  _globals['_UPDATEFINETUNINGJOBREQUEST']._serialized_end=4050
  _globals['_DELETEFINETUNINGJOBREQUEST']._serialized_start=4052
  _globals['_DELETEFINETUNINGJOBREQUEST']._serialized_end=4100
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/user.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/user.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from ..google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12gateway/user.proto\x12\x07gateway\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/api/visibility.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xce\x04\n\x04User\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\'\n\nfirst_name\x18\t \x01(\tB\x13\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\t\x12\x07UI_ONLY\x12&\n\tlast_name\x18\n \x01(\tB\x13\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\t\x12\x07UI_ONLY\x12(\n\x0bstated_role\x18\x0b \x01(\tB\x13\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\t\x12\x07UI_ONLY\x12\x36\n\x0b\x63reate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x12\n\x04role\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02\x12\x14\n\x05\x65mail\x18\x04 \x01(\tB\x05\xe2\x41\x02\x02\x05\x12)\n\x05state\x18\x06 \x01(\x0e\x32\x13.gateway.User.StateB\x05\xe2\x41\x02\x03\x05\x12&\n\x06status\x18\x07 \x01(\x0b\x32\x0f.gateway.StatusB\x05\xe2\x41\x02\x03\x05\x12\x35\n\x0bupdate_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\"S\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\x0c\n\x08UPDATING\x10\x03\x12\x0c\n\x08\x44\x45LETING\x10\x04:Y\xea\x41I\n\x15\x61pi.fireworks.ai/User\x12#accounts/{AccountId}/users/{UserId}*\x05users2\x04user\x82\xf1\x04\t\n\x07\x41\x63\x63ount\"c\n\x11\x43reateUserRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12!\n\x04user\x18\x02 \x01(\x0b\x32\r.gateway.UserB\x04\xe2\x41\x01\x02\x12\x15\n\x07user_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\"$\n\x0eGetUserRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\x89\x01\n\x10ListUsersRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"^\n\x11ListUsersResponse\x12\x1c\n\x05users\x18\x01 \x03(\x0b\x32\r.gateway.User\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"m\n\x11UpdateUserRequest\x12!\n\x04user\x18\x01 \x01(\x0b\x32\r.gateway.UserB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"\'\n\x11\x44\x65leteUserRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.user_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_USER'].fields_by_name['name']._loaded_options = None
  _globals['_USER'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_USER'].fields_by_name['display_name']._loaded_options = None
  _globals['_USER'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_USER'].fields_by_name['first_name']._loaded_options = None
  _globals['_USER'].fields_by_name['first_name']._serialized_options = b'\342A\001\001\372\322\344\223\002\t\022\007UI_ONLY'
  _globals['_USER'].fields_by_name['last_name']._loaded_options = None
  _globals['_USER'].fields_by_name['last_name']._serialized_options = b'\342A\001\001\372\322\344\223\002\t\022\007UI_ONLY'
  _globals['_USER'].fields_by_name['stated_role']._loaded_options = None
  _globals['_USER'].fields_by_name['stated_role']._serialized_options = b'\342A\001\001\372\322\344\223\002\t\022\007UI_ONLY'
  _globals['_USER'].fields_by_name['create_time']._loaded_options = None
  _globals['_USER'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_USER'].fields_by_name['role']._loaded_options = None
  _globals['_USER'].fields_by_name['role']._serialized_options = b'\342A\001\002'
  _globals['_USER'].fields_by_name['email']._loaded_options = None
  _globals['_USER'].fields_by_name['email']._serialized_options = b'\342A\002\002\005'
  _globals['_USER'].fields_by_name['state']._loaded_options = None
  _globals['_USER'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_USER'].fields_by_name['status']._loaded_options = None
  _globals['_USER'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_USER'].fields_by_name['update_time']._loaded_options = None
  _globals['_USER'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_USER']._loaded_options = None
  _globals['_USER']._serialized_options = b'\352AI\n\025api.fireworks.ai/User\022#accounts/{AccountId}/users/{UserId}*\005users2\004user\202\361\004\t\n\007Account'
  _globals['_CREATEUSERREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEUSERREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEUSERREQUEST'].fields_by_name['user']._loaded_options = None
  _globals['_CREATEUSERREQUEST'].fields_by_name['user']._serialized_options = b'\342A\001\002'
  _globals['_CREATEUSERREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_CREATEUSERREQUEST'].fields_by_name['user_id']._serialized_options = b'\342A\001\001'
  _globals['_GETUSERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETUSERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_LISTUSERSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTUSERSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTUSERSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTUSERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTUSERSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTUSERSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTUSERSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTUSERSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTUSERSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTUSERSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEUSERREQUEST'].fields_by_name['user']._loaded_options = None
  _globals['_UPDATEUSERREQUEST'].fields_by_name['user']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEUSERREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEUSERREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_DELETEUSERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEUSERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_USER']._serialized_start=233
  _globals['_USER']._serialized_end=823
  _globals['_USER_STATE']._serialized_start=649
  _globals['_USER_STATE']._serialized_end=732
  _globals['_CREATEUSERREQUEST']._serialized_start=825
  _globals['_CREATEUSERREQUEST']._serialized_end=924
  _globals['_GETUSERREQUEST']._serialized_start=926
  _globals['_GETUSERREQUEST']._serialized_end=962
  _globals['_LISTUSERSREQUEST']._serialized_start=965
  _globals['_LISTUSERSREQUEST']._serialized_end=1102
  _globals['_LISTUSERSRESPONSE']._serialized_start=1104
  _globals['_LISTUSERSRESPONSE']._serialized_end=1198
  _globals['_UPDATEUSERREQUEST']._serialized_start=1200
  _globals['_UPDATEUSERREQUEST']._serialized_end=1309
  _globals['_DELETEUSERREQUEST']._serialized_start=1311
  _globals['_DELETEUSERREQUEST']._serialized_end=1350
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/options.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/options.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15gateway/options.proto\x12\x07gateway\x1a google/protobuf/descriptor.proto\"Q\n\x0b\x41piResource\x12\x13\n\x0bparent_type\x18\x01 \x01(\t\x12\x11\n\tskip_gorm\x18\x02 \x01(\x08\x12\x1a\n\x12has_db_only_fields\x18\x03 \x01(\x08:O\n\x0c\x61pi_resource\x12\x1f.google.protobuf.MessageOptions\x18\x90N \x01(\x0b\x32\x14.gateway.ApiResource\x88\x01\x01:3\n\x08\x61pi_only\x12\x1d.google.protobuf.FieldOptions\x18\x93N \x01(\x08\x88\x01\x01:4\n\tgorm_json\x12\x1d.google.protobuf.FieldOptions\x18\x94N \x01(\x08\x88\x01\x01:7\n\x0cshow_if_zero\x12\x1d.google.protobuf.FieldOptions\x18\x95N \x01(\x08\x88\x01\x01:2\n\ngorm_index\x12\x1d.google.protobuf.FieldOptions\x18\x96N \x01(\x08:9\n\x11gorm_unique_index\x12\x1d.google.protobuf.FieldOptions\x18\x97N \x01(\x08:?\n\x17gorm_unique_named_index\x12\x1d.google.protobuf.FieldOptions\x18\x98N \x01(\tBCZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.options_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_APIRESOURCE']._serialized_start=68
  _globals['_APIRESOURCE']._serialized_end=149
# @@protoc_insertion_point(module_scope)
